@@ -3,7 +3,7 @@ package # hide from CPAN
 
 use PDL;
 use Photonic::Geometry::FromB;
-use Photonic::LE::NR2::AllH;
+use Photonic::LE::NR2::Haydock;
 use Machine::Epsilon;
 use File::Temp qw(tempdir);
 use File::Spec::Functions;
@@ -20,7 +20,7 @@ sub make_fn { catfile tempdir(CLEANUP => 1), "remStore.dat" }
 sub make_store {
     my ($B, $d0, $nh, $ah_args) = @_;
     my $g=Photonic::Geometry::FromB->new(B=>$B, Direction0=>pdl($d0)); #long
-    my $a=Photonic::LE::NR2::AllH->new(geometry=>$g, nh=>$nh, %$ah_args);
+    my $a=Photonic::LE::NR2::Haydock->new(geometry=>$g, nh=>$nh, %$ah_args);
     $a->run;
     ($a, $g);
 }
